BybitExecClientConfigBuilder

Struct BybitExecClientConfigBuilder 

pub struct BybitExecClientConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> BybitExecClientConfigBuilder<S>

pub fn build(self) -> BybitExecClientConfig
where S: IsComplete,

Finish building and return the requested object

pub fn api_key( self, value: String, ) -> BybitExecClientConfigBuilder<SetApiKey<S>>
where S::ApiKey: IsUnset,

Optional (Some / Option setters). API key for authenticated requests.

pub fn maybe_api_key( self, value: Option<String>, ) -> BybitExecClientConfigBuilder<SetApiKey<S>>
where S::ApiKey: IsUnset,

Optional (Some / Option setters). API key for authenticated requests.

pub fn api_secret( self, value: String, ) -> BybitExecClientConfigBuilder<SetApiSecret<S>>
where S::ApiSecret: IsUnset,

Optional (Some / Option setters). API secret for authenticated requests.

pub fn maybe_api_secret( self, value: Option<String>, ) -> BybitExecClientConfigBuilder<SetApiSecret<S>>
where S::ApiSecret: IsUnset,

Optional (Some / Option setters). API secret for authenticated requests.

pub fn product_types( self, value: Vec<BybitProductType>, ) -> BybitExecClientConfigBuilder<SetProductTypes<S>>
where S::ProductTypes: IsUnset,

Optional (Some / Option setters). Default: vec![BybitProductType::Linear].

Product types to support (e.g., Linear, Spot, Inverse, Option).

pub fn maybe_product_types( self, value: Option<Vec<BybitProductType>>, ) -> BybitExecClientConfigBuilder<SetProductTypes<S>>
where S::ProductTypes: IsUnset,

Optional (Some / Option setters). Default: vec![BybitProductType::Linear].

Product types to support (e.g., Linear, Spot, Inverse, Option).

pub fn environment( self, value: BybitEnvironment, ) -> BybitExecClientConfigBuilder<SetEnvironment<S>>
where S::Environment: IsUnset,

Optional (Some / Option setters). Default: BybitEnvironment::Mainnet.

Environment selection (Mainnet, Testnet, Demo).

pub fn maybe_environment( self, value: Option<BybitEnvironment>, ) -> BybitExecClientConfigBuilder<SetEnvironment<S>>
where S::Environment: IsUnset,

Optional (Some / Option setters). Default: BybitEnvironment::Mainnet.

Environment selection (Mainnet, Testnet, Demo).

pub fn base_url_http( self, value: String, ) -> BybitExecClientConfigBuilder<SetBaseUrlHttp<S>>
where S::BaseUrlHttp: IsUnset,

Optional (Some / Option setters). Optional override for the REST base URL.

pub fn maybe_base_url_http( self, value: Option<String>, ) -> BybitExecClientConfigBuilder<SetBaseUrlHttp<S>>
where S::BaseUrlHttp: IsUnset,

Optional (Some / Option setters). Optional override for the REST base URL.

pub fn base_url_ws_private( self, value: String, ) -> BybitExecClientConfigBuilder<SetBaseUrlWsPrivate<S>>
where S::BaseUrlWsPrivate: IsUnset,

Optional (Some / Option setters). Optional override for the private WebSocket URL.

pub fn maybe_base_url_ws_private( self, value: Option<String>, ) -> BybitExecClientConfigBuilder<SetBaseUrlWsPrivate<S>>
where S::BaseUrlWsPrivate: IsUnset,

Optional (Some / Option setters). Optional override for the private WebSocket URL.

pub fn base_url_ws_trade( self, value: String, ) -> BybitExecClientConfigBuilder<SetBaseUrlWsTrade<S>>
where S::BaseUrlWsTrade: IsUnset,

Optional (Some / Option setters). Optional override for the trade WebSocket URL.

pub fn maybe_base_url_ws_trade( self, value: Option<String>, ) -> BybitExecClientConfigBuilder<SetBaseUrlWsTrade<S>>
where S::BaseUrlWsTrade: IsUnset,

Optional (Some / Option setters). Optional override for the trade WebSocket URL.

pub fn proxy_url( self, value: String, ) -> BybitExecClientConfigBuilder<SetProxyUrl<S>>
where S::ProxyUrl: IsUnset,

Optional (Some / Option setters). Optional proxy URL for HTTP and WebSocket transports.

pub fn maybe_proxy_url( self, value: Option<String>, ) -> BybitExecClientConfigBuilder<SetProxyUrl<S>>
where S::ProxyUrl: IsUnset,

Optional (Some / Option setters). Optional proxy URL for HTTP and WebSocket transports.

pub fn http_timeout_secs( self, value: u64, ) -> BybitExecClientConfigBuilder<SetHttpTimeoutSecs<S>>
where S::HttpTimeoutSecs: IsUnset,

Optional (Some / Option setters). Default: 60.

REST timeout in seconds.

pub fn maybe_http_timeout_secs( self, value: Option<u64>, ) -> BybitExecClientConfigBuilder<SetHttpTimeoutSecs<S>>
where S::HttpTimeoutSecs: IsUnset,

Optional (Some / Option setters). Default: 60.

REST timeout in seconds.

pub fn max_retries( self, value: u32, ) -> BybitExecClientConfigBuilder<SetMaxRetries<S>>
where S::MaxRetries: IsUnset,

Optional (Some / Option setters). Default: 3.

Maximum retry attempts for REST requests.

pub fn maybe_max_retries( self, value: Option<u32>, ) -> BybitExecClientConfigBuilder<SetMaxRetries<S>>
where S::MaxRetries: IsUnset,

Optional (Some / Option setters). Default: 3.

Maximum retry attempts for REST requests.

pub fn retry_delay_initial_ms( self, value: u64, ) -> BybitExecClientConfigBuilder<SetRetryDelayInitialMs<S>>
where S::RetryDelayInitialMs: IsUnset,

Optional (Some / Option setters). Default: 1_000.

Initial retry backoff in milliseconds.

pub fn maybe_retry_delay_initial_ms( self, value: Option<u64>, ) -> BybitExecClientConfigBuilder<SetRetryDelayInitialMs<S>>
where S::RetryDelayInitialMs: IsUnset,

Optional (Some / Option setters). Default: 1_000.

Initial retry backoff in milliseconds.

pub fn retry_delay_max_ms( self, value: u64, ) -> BybitExecClientConfigBuilder<SetRetryDelayMaxMs<S>>
where S::RetryDelayMaxMs: IsUnset,

Optional (Some / Option setters). Default: 10_000.

Maximum retry backoff in milliseconds.

pub fn maybe_retry_delay_max_ms( self, value: Option<u64>, ) -> BybitExecClientConfigBuilder<SetRetryDelayMaxMs<S>>
where S::RetryDelayMaxMs: IsUnset,

Optional (Some / Option setters). Default: 10_000.

Maximum retry backoff in milliseconds.

pub fn heartbeat_interval_secs( self, value: u64, ) -> BybitExecClientConfigBuilder<SetHeartbeatIntervalSecs<S>>
where S::HeartbeatIntervalSecs: IsUnset,

Optional (Some / Option setters). Default: 5.

Heartbeat interval in seconds for WebSocket clients.

pub fn maybe_heartbeat_interval_secs( self, value: Option<u64>, ) -> BybitExecClientConfigBuilder<SetHeartbeatIntervalSecs<S>>
where S::HeartbeatIntervalSecs: IsUnset,

Optional (Some / Option setters). Default: 5.

Heartbeat interval in seconds for WebSocket clients.

pub fn recv_window_ms( self, value: u64, ) -> BybitExecClientConfigBuilder<SetRecvWindowMs<S>>
where S::RecvWindowMs: IsUnset,

Optional (Some / Option setters). Default: 5_000.

Receive window in milliseconds for signed requests.

pub fn maybe_recv_window_ms( self, value: Option<u64>, ) -> BybitExecClientConfigBuilder<SetRecvWindowMs<S>>
where S::RecvWindowMs: IsUnset,

Optional (Some / Option setters). Default: 5_000.

Receive window in milliseconds for signed requests.

pub fn account_id( self, value: AccountId, ) -> BybitExecClientConfigBuilder<SetAccountId<S>>
where S::AccountId: IsUnset,

Optional (Some / Option setters). Optional account identifier to associate with the execution client.

pub fn maybe_account_id( self, value: Option<AccountId>, ) -> BybitExecClientConfigBuilder<SetAccountId<S>>
where S::AccountId: IsUnset,

Optional (Some / Option setters). Optional account identifier to associate with the execution client.

pub fn use_spot_position_reports( self, value: bool, ) -> BybitExecClientConfigBuilder<SetUseSpotPositionReports<S>>
where S::UseSpotPositionReports: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to generate position reports from wallet balances for SPOT positions.

pub fn maybe_use_spot_position_reports( self, value: Option<bool>, ) -> BybitExecClientConfigBuilder<SetUseSpotPositionReports<S>>
where S::UseSpotPositionReports: IsUnset,

Optional (Some / Option setters). Default: false.

Whether to generate position reports from wallet balances for SPOT positions.

pub fn futures_leverages( self, value: HashMap<String, u32>, ) -> BybitExecClientConfigBuilder<SetFuturesLeverages<S>>
where S::FuturesLeverages: IsUnset,

Optional (Some / Option setters). Leverage configuration for futures (symbol -> leverage).

pub fn maybe_futures_leverages( self, value: Option<HashMap<String, u32>>, ) -> BybitExecClientConfigBuilder<SetFuturesLeverages<S>>
where S::FuturesLeverages: IsUnset,

Optional (Some / Option setters). Leverage configuration for futures (symbol -> leverage).

pub fn position_mode( self, value: HashMap<String, BybitPositionMode>, ) -> BybitExecClientConfigBuilder<SetPositionMode<S>>
where S::PositionMode: IsUnset,

Optional (Some / Option setters). Position mode configuration for symbols (symbol -> mode).

pub fn maybe_position_mode( self, value: Option<HashMap<String, BybitPositionMode>>, ) -> BybitExecClientConfigBuilder<SetPositionMode<S>>
where S::PositionMode: IsUnset,

Optional (Some / Option setters). Position mode configuration for symbols (symbol -> mode).

pub fn margin_mode( self, value: BybitMarginMode, ) -> BybitExecClientConfigBuilder<SetMarginMode<S>>
where S::MarginMode: IsUnset,

Optional (Some / Option setters). Unified margin mode setting.

pub fn maybe_margin_mode( self, value: Option<BybitMarginMode>, ) -> BybitExecClientConfigBuilder<SetMarginMode<S>>
where S::MarginMode: IsUnset,

Optional (Some / Option setters). Unified margin mode setting.

pub fn transport_backend( self, value: TransportBackend, ) -> BybitExecClientConfigBuilder<SetTransportBackend<S>>
where S::TransportBackend: IsUnset,

Optional (Some / Option setters). Default: <TransportBackend as Default>::default().

WebSocket transport backend (defaults to Tungstenite).

pub fn maybe_transport_backend( self, value: Option<TransportBackend>, ) -> BybitExecClientConfigBuilder<SetTransportBackend<S>>
where S::TransportBackend: IsUnset,

Optional (Some / Option setters). Default: <TransportBackend as Default>::default().

WebSocket transport backend (defaults to Tungstenite).